"use strict";

var _graphqlCompose = require("graphql-compose");

var _graphql = require("graphql");

var _AwsServiceOperation = require("../AwsServiceOperation");

var _AwsConfigITC = _interopRequireDefault(require("../types/AwsConfigITC"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable class-methods-use-this */
const operations = {
  CreateBucket: {
    http: {
      method: 'PUT',
      requestUri: '/{Bucket}'
    },
    input: {
      type: 'structure',
      required: ['Bucket'],
      members: {
        ACL: {
          location: 'header',
          locationName: 'x-amz-acl'
        },
        Bucket: {
          location: 'uri',
          locationName: 'Bucket'
        },
        CreateBucketConfiguration: {
          locationName: 'CreateBucketConfiguration',
          xmlNamespace: {
            uri: 'http://s3.amazonaws.com/doc/2006-03-01/'
          },
          type: 'structure',
          members: {
            LocationConstraint: {}
          }
        },
        GrantFullControl: {
          location: 'header',
          locationName: 'x-amz-grant-full-control'
        },
        GrantRead: {
          location: 'header',
          locationName: 'x-amz-grant-read'
        },
        GrantReadACP: {
          location: 'header',
          locationName: 'x-amz-grant-read-acp'
        },
        GrantWrite: {
          location: 'header',
          locationName: 'x-amz-grant-write'
        },
        GrantWriteACP: {
          location: 'header',
          locationName: 'x-amz-grant-write-acp'
        }
      },
      payload: 'CreateBucketConfiguration'
    },
    output: {
      type: 'structure',
      members: {
        Location: {
          location: 'header',
          locationName: 'Location'
        }
      }
    },
    alias: 'PutBucket'
  }
};
describe('AwsJsonParserOperation', () => {
  const AWSMock = {
    S3: class S3 {
      CreateBucket(args, cb) {} // eslint-disable-line


    }
  };
  const oper = new _AwsServiceOperation.AwsServiceOperation({
    prefix: 'AWS',
    serviceId: 'S3',
    name: 'CreateBucket',
    config: operations.CreateBucket,
    awsSDK: AWSMock,
    shapes: {}
  });
  it('getTypeName()', () => {
    expect(oper.getTypeName()).toBe('AWSS3CreateBucket');
  });
  it('getType()', () => {
    const tc = oper.getType();
    expect(tc).toBeInstanceOf(_graphql.GraphQLObjectType);
  });
  it('getArgs()', () => {
    const args = oper.getArgs();
    expect(args.input).toBeDefined(); // input arg has required fields, so it wrapped by NonNullComposer

    expect(args.input.type).toBeInstanceOf(_graphqlCompose.NonNullComposer);
    expect(args.input.type.ofType).toBeInstanceOf(_graphqlCompose.InputTypeComposer);
    expect(args.input.type.ofType.getTypeName()).toBe('AWSS3CreateBucketInput');
  });
  describe('getResolve()', () => {
    const resolve = oper.getResolve();
    it('to be function', () => {
      expect(resolve.call).toBeDefined();
    });
    it('resolves', async () => {
      AWSMock.S3 = class S3WithPayload {
        CreateBucket(args, cb) {
          cb(undefined, {
            payload: args
          });
        }

      };
      const res = await resolve({}, {
        input: {
          arg: 123
        }
      }, {}, {});
      expect(res).toEqual({
        payload: {
          arg: 123
        }
      });
    });
    it('rejects', async () => {
      AWSMock.S3 = class S3WithError {
        CreateBucket(args, cb) {
          cb('err');
        }

      };
      expect.assertions(1);

      try {
        await resolve({}, {}, {}, {});
      } catch (e) {
        expect(e).toBe('err');
      }
    });
  });
  it('getFieldConfig()', () => {
    const fc = oper.getFieldConfig();
    expect(fc.type).toBeInstanceOf(_graphql.GraphQLObjectType);
    expect(fc.args.config.type).toBe(_AwsConfigITC.default.getType());
    expect(fc.resolve.call).toBeDefined();
  });
});